@@ -223,13 +223,7 @@ void PlaylistBox::duplicate()
 
 void PlaylistBox::scanFolders()
 {
-    qCDebug(JUK_LOG) << "Starting folder scan";
-    QTime stopwatch; stopwatch.start();
-
     PlaylistCollection::scanFolders();
-
-    qCDebug(JUK_LOG) << "Folder scan complete, took" << stopwatch.elapsed() << "ms";
-    qCDebug(JUK_LOG) << "Startup complete!";
     emit startupComplete();
 }
 
@@ -269,13 +263,15 @@ void PlaylistBox::slotSetHistoryPlaylistEnabled(bool enable)
 
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName)
 {
-    setupPlaylist(playlist, iconName, 0);
+    setupPlaylist(playlist, iconName, nullptr);
 }
 
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName, Item *parentItem)
 {
-    connect(playlist, SIGNAL(signalPlaylistItemsDropped(Playlist*)),
-            SLOT(slotPlaylistItemsDropped(Playlist*)));
+    connect(playlist, &Playlist::signalPlaylistItemsDropped,
+            this,     &PlaylistBox::slotPlaylistItemsDropped);
+    connect(playlist, &Playlist::signalMoveFocusAway,
+            this,     &PlaylistBox::signalMoveFocusAway);
 
     PlaylistCollection::setupPlaylist(playlist, iconName);
 
