@@ -41,10 +41,10 @@ class PlayerManager;
 class FileHandle;
 
 template<class T>
-class QList;
+class QVector;
 
-typedef QList<PlaylistItem *> PlaylistItemList;
-typedef QList<Playlist *> PlaylistList;
+typedef QVector<PlaylistItem *> PlaylistItemList;
+typedef QVector<Playlist *> PlaylistList;
 
 class PlaylistCollection : public PlaylistInterface
 {
@@ -171,14 +171,6 @@ public:
      */
     QStringList excludedFolders() const { return m_excludedFolderList; }
 
-    /**
-     * This is used to put up a temporary widget over the top of the playlist
-     * stack.  This is part of a trick to significantly speed up painting by
-     * hiding the playlist to which items are being added.
-     */
-    void raiseDistraction();
-    void lowerDistraction();
-
     class ActionHandler;
     friend PlaylistCollection::ActionHandler;
 
